# django-filtersignals

filtersignals are prioritized signals, that allow each signal receiver to modify the data provided to them, as processed by other receivers before them.

This allows you to easily implement a system of filter hooks in your Django project.